<?php
/**
 * @description: API for communication with labelcall rest service
 * @author: ENDORA
 * @website: www.endora.pl
 * 
 * API for communication with labelcall rest service
 */

namespace labelcall;

require_once dirname( __FILE__ )  .'/../config.php';

if (!class_exists('LabelCallApi')) {
	class LabelCallApi {
		const DEVICE_STATUS_ACTIVE = 'active';
		const DEVICE_STATUS_INACTIVE = 'inactive';

		const PROPERTY_TYPE_NAME = 'cname'; // only for property cname
		const PROPERTY_TYPE_DATE = 'date';
		const PROPERTY_TYPE_LABEL = 'label'; // up to 50 chars
		const PROPERTY_TYPE_AMOUNT = 'amount';
		const PROPERTY_TYPE_NUMBER = 'number';
		const PROPERTY_TYPE_DECIMAL = 'decimal';
		const PROPERTY_TYPE_BOOL = 'bool';
		const PROPERTY_TYPE_DESCRIPTION = 'description'; // up to 140 chars

		public function __construct( $masterAccountId, $apiKey) {
			$this->masterAccountId = $masterAccountId;
			$this->apiKey = $apiKey;
		}

		/* Contact methods */
		public function upsertContact ( $phoneNumber, $props) {
			return $this->makeRequest('/api/v1.0/contact/Upsert', 'POST', ['PhoneNumber' => $phoneNumber, 'MasterAccountId' => $this->masterAccountId, 'Properties' => $props]);
		}

		public function createContact ( $phoneNumber) {
			return $this->makeRequest('/api/v1.0/contact', 'POST', ['phoneNumber' => $phoneNumber]);
		}

		public function getContact ( $phoneNumber) {
			return $this->makeRequest('/api/v1.0/contact/search', 'GET', ['phoneNumber' => $phoneNumber, $this->master]);
		}

		public function deleteContact ( $contactId) {
			return $this->makeRequest('/api/v1.0/contact/' . $contactId, 'DELETE');
		}
		/* Contact methods -- End*/

		public function removeIntegration() {
			return $this->makeRequest(
				'/woocommerce/api/v1.0/settings/removeIntegration?domain=' . explode('//', get_site_url())[1],
				'DELETE'
			);
		}

		private function makeRequest ( $url, $method, $fields = [], $sendHeaders = true) {
			if ($sendHeaders) {
				$headers = [
					'lc-master-account: ' . $this->masterAccountId,
					'lc-api-key: ' . $this->apiKey,
					'Content-Type: application/json'
				];
			}
	
			$url = \Config::$lc_url . $url;
	
			$ch = curl_init();
			if (count($fields) > 0) {
				if ('POST' == $method || 'PUT' == $method ) {
					$body = json_encode($fields);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $body);
				} else {
					$fieldsString = http_build_query($fields);
					$url .= '?' . $fieldsString;
				}
			}
	
			if ($sendHeaders) {
				curl_setopt($ch, CURLOPT_HTTPHEADER, $headers); // set headers
				curl_setopt($ch, CURLOPT_HEADER , false);  // we want headers
			}
			
			curl_setopt($ch, CURLOPT_URL, $url); // set url
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // return the transfer as a string
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); //stop cURL from verifying the peer's certificate
	
			curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $method);
			$result = curl_exec ($ch);
			$status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
			
			// //tests only
			// file_put_contents('./endpointsTest.txt', "\nMETHOD: " . $method . "\nURL: " . $url . "\nDATA: " . print_r($fields, true) . "\n STATUS: \n " . $status . "\n RESULT: \n " . print_r($result, true), FILE_APPEND, null);
			// //tests only
	
			curl_close ($ch);
	
			return json_decode($result, true);
	
		}
	}
}
