<?php
/*
Plugin Name: Labelcall
Plugin URI: http://labelcall.com
Description: Labelcall - Shows your Customer data on your phone before you pick up call. Enable you to devlier personalized customer experience, significantly reduces the talk time.
Author: Labelcall
Version: 1.6.0
License URI:  https://www.gnu.org/licenses/gpl-2.0.html
Author URI: https://labelcall.com
License: Commercial

{Plugin Name} is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.

{Plugin Name} is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with {Plugin Name}. If not, see {License URI}.
*/
/**
 * Required file
 */
require_once dirname( __FILE__ ) . '/api/restApi.php';
require_once dirname( __FILE__ ) . '/config.php';

$dev_url = 'http://localhost:32700';
$stage_url = 'https://stage-api.labelcall.com';
$prod_url = 'https://api.labelcall.com';

$dev_portal_url = 'https://localhost:32776';
$stage_portal_url = 'https://stage-portal.labelcall.com';
$prod_portal_url = 'https://portal.labelcall.com';

if (Config::APP_MODE == DEV) {
	Config::$lc_url = $dev_url;
	Config::$lc_portal_url = $dev_portal_url;
} else if (Config::APP_MODE == STAGE) {
	Config::$lc_url = $stage_url;
	Config::$lc_portal_url = $stage_portal_url;
} else if (Config::APP_MODE == PROD) {
	Config::$lc_url = $prod_url;
	Config::$lc_portal_url = $prod_portal_url;
}

/**
 * Exit if accessed directly.
 */
if (!defined('ABSPATH')) {
	exit;
}

/**
 * Include the main LabelCall class.
 */
if (!class_exists( 'LabelCall' )) {
	include_once dirname( __FILE__ ) . '/includes/LabelCall.php';
}

/**
 * Main instance of LabelCall
 * Returns the main instance of LabelCall to prevent the need to use globals.
 *
 * @since  1.0
 * @return LabelCall
 */
function lc() {
	return labelcall\LabelCall::instance();
}

/**
 * Check require conditions and then activate plugin
 *
 * @return bool
 */
function labelcall_check_conditions() {
	if (!class_exists('WC_Payment_Gateway'))	{
		add_action('admin_init', 'child_plugin_has_parent_plugin');

		/**
		 * Check if exist a parent plugin (woocommerce)
		 */
		function child_plugin_has_parent_plugin() {
			if (is_admin() && current_user_can('activate_plugins') && !is_plugin_active('woocommerce/woocommerce.php')) {
				add_action('admin_notices', 'child_plugin_notice');

				deactivate_plugins(plugin_basename(__FILE__));

				if (isset($_GET['activate'])) {
					unset($_GET['activate']);
				}
			}
		}


		/**
		 * Show notice when parent plugin is inactive
		 *
		 * @return bool
		 */
		function child_plugin_notice() {
			echo '<div class="error"><p>', esc_html__('The Labelcall module requires WooCommerce to run, you can download it', 'woocommerce'), ' <a target="blank" href="https://wordpress.org/plugins/woocommerce/">', esc_html__('here', 'woocommerce'), '</a></p></div>';
			return false;
		}

		return false;
	}

	return true;
}

/**
 * Create admin options page
 */
function labelcall_options_page() {
	add_menu_page(
		'Labelcall',
		'Labelcall',
		'manage_options',
		plugin_dir_path(__FILE__) . 'templates/index.php',
		null,
		null, //@todo: change to icon
		20
	);
}

function labelcall_plugin_uninstall() {
	$labelcall = lc();
	$labelcall->removeIntegration();
}

/**
 *  Register external js and css script
 */
function labelcall_external_script( $hook_suffix) {
	if ('labelcall/templates/index.php' == $hook_suffix) {
		/**
		 *  Register style
		 */
		wp_register_style('labelcall_bootstrap', plugins_url('/assets/css/bootstrap.css', __FILE__), [], '4.0.0-beta');
		wp_register_style('labelcall_custom_css', plugins_url('/assets/css/labelcall.css', __FILE__), [], '1.0');

		/**
		 * Register js
		 */
		wp_register_script('labelcall_jquery', plugins_url( '/assets/js/jquery-3.2.1.min.js', __FILE__ ), [], '3.2.1');

		/**
		 * Enqueue style
		 */
		wp_enqueue_style('labelcall_bootstrap');
		wp_enqueue_style('labelcall_custom_css');

		/**
		 * Enqueue js
		 */
		wp_enqueue_script('labelcall_jquery');
	}
}

function labelcall_admin_styles() {
	wp_register_style('labelcall-admin', plugins_url('/assets/css/labelcall-admin.css', __FILE__), [], '1.0');
	wp_enqueue_style('labelcall-admin');
}

add_action('admin_head', 'labelcall_admin_styles');

/**
 * Basic actions and hooks
 */
add_action('admin_enqueue_scripts', 'labelcall_external_script');
add_action('plugins_loaded', 'labelcall_check_conditions');
add_action('admin_menu', 'labelcall_options_page');

register_uninstall_hook(__FILE__, 'labelcall_plugin_uninstall');

add_action( 'rest_api_init', function () {
	register_rest_route( 'labelcall/api/v1', '/saveCridentials', array(
		'methods' => 'POST',
		'callback' => 'saveCridentials',
	));
});

function cron_fetch_data() {
	$usersQuery = new WP_User_Query(array(
		'role' => 'customer'
	));

	if ($usersQuery->get_total() > 0) {
		$labelcall = \labelcall\LabelCall::instance();
		$results = $usersQuery->get_results();
		foreach ($results as $user) {
			$customer = new WC_Customer($user->id);
			if ($customer->get_last_order()) {
				$labelcall->user_profile_update_by_profile(null, $customer->get_last_order());
			} else {
				$labelcall->user_profile_update_by_profile($user->id);
			}
		}
	}
}

add_action('full_contacts_sync', 'cron_fetch_data');

lc();
